/* NotificationFilter.c generated by valac 0.56.19, the Vala compiler
 * generated from NotificationFilter.vala, do not modify */

#include <glib-object.h>
#include <gtk/gtk.h>
#include <json-glib/json-glib.h>
#include <glib.h>
#include <stdlib.h>
#include <string.h>
#include <gobject/gvaluecollector.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

#define TUBA_API_TYPE_NOTIFICATION_FILTER (tuba_api_notification_filter_get_type ())
#define TUBA_API_NOTIFICATION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_NOTIFICATION_FILTER, TubaAPINotificationFilter))
#define TUBA_API_NOTIFICATION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_NOTIFICATION_FILTER, TubaAPINotificationFilterClass))
#define TUBA_API_IS_NOTIFICATION_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_NOTIFICATION_FILTER))
#define TUBA_API_IS_NOTIFICATION_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_NOTIFICATION_FILTER))
#define TUBA_API_NOTIFICATION_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_NOTIFICATION_FILTER, TubaAPINotificationFilterClass))

typedef struct _TubaAPINotificationFilter TubaAPINotificationFilter;
typedef struct _TubaAPINotificationFilterClass TubaAPINotificationFilterClass;
typedef struct _TubaAPINotificationFilterPrivate TubaAPINotificationFilterPrivate;

#define TUBA_TYPE_WIDGETIZABLE (tuba_widgetizable_get_type ())
#define TUBA_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizable))
#define TUBA_IS_WIDGETIZABLE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_WIDGETIZABLE))
#define TUBA_WIDGETIZABLE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), TUBA_TYPE_WIDGETIZABLE, TubaWidgetizableIface))

typedef struct _TubaWidgetizable TubaWidgetizable;
typedef struct _TubaWidgetizableIface TubaWidgetizableIface;

#define TUBA_TYPE_ENTITY (tuba_entity_get_type ())
#define TUBA_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_ENTITY, TubaEntity))
#define TUBA_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_ENTITY, TubaEntityClass))
#define TUBA_IS_ENTITY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_ENTITY))
#define TUBA_IS_ENTITY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_ENTITY))
#define TUBA_ENTITY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_ENTITY, TubaEntityClass))

typedef struct _TubaEntity TubaEntity;
typedef struct _TubaEntityClass TubaEntityClass;

#define TUBA_API_TYPE_ACCOUNT (tuba_api_account_get_type ())
#define TUBA_API_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccount))
#define TUBA_API_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))
#define TUBA_API_IS_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_IS_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_TYPE_ACCOUNT))
#define TUBA_API_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_TYPE_ACCOUNT, TubaAPIAccountClass))

typedef struct _TubaAPIAccount TubaAPIAccount;
typedef struct _TubaAPIAccountClass TubaAPIAccountClass;

#define TUBA_TYPE_INSTANCE_ACCOUNT (tuba_instance_account_get_type ())
#define TUBA_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccount))
#define TUBA_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))
#define TUBA_IS_INSTANCE_ACCOUNT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_IS_INSTANCE_ACCOUNT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_TYPE_INSTANCE_ACCOUNT))
#define TUBA_INSTANCE_ACCOUNT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_TYPE_INSTANCE_ACCOUNT, TubaInstanceAccountClass))

typedef struct _TubaInstanceAccount TubaInstanceAccount;
typedef struct _TubaInstanceAccountClass TubaInstanceAccountClass;
typedef struct _TubaEntityPrivate TubaEntityPrivate;

#define TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY (tuba_api_notification_filter_policy_get_type ())
#define TUBA_API_NOTIFICATION_FILTER_POLICY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicy))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicyClass))
#define TUBA_API_NOTIFICATION_FILTER_IS_POLICY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY))
#define TUBA_API_NOTIFICATION_FILTER_IS_POLICY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicyClass))

typedef struct _TubaAPINotificationFilterPolicy TubaAPINotificationFilterPolicy;
typedef struct _TubaAPINotificationFilterPolicyClass TubaAPINotificationFilterPolicyClass;
typedef struct _TubaAPINotificationFilterPolicyPrivate TubaAPINotificationFilterPolicyPrivate;

#define TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY (tuba_api_notification_filter_policy_summary_get_type ())
#define TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummary))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummaryClass))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_IS_SUMMARY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_IS_SUMMARY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY))
#define TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummaryClass))

typedef struct _TubaAPINotificationFilterPolicySummary TubaAPINotificationFilterPolicySummary;
typedef struct _TubaAPINotificationFilterPolicySummaryClass TubaAPINotificationFilterPolicySummaryClass;
enum  {
	TUBA_API_NOTIFICATION_FILTER_POLICY_0_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_NUM_PROPERTIES];
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _TubaAPINotificationFilterPolicySummaryPrivate TubaAPINotificationFilterPolicySummaryPrivate;
enum  {
	TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_0_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_filter_policy_summary_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_NUM_PROPERTIES];

#define TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST (tuba_api_notification_filter_request_get_type ())
#define TUBA_API_NOTIFICATION_FILTER_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequest))
#define TUBA_API_NOTIFICATION_FILTER_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequestClass))
#define TUBA_API_NOTIFICATION_FILTER_IS_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST))
#define TUBA_API_NOTIFICATION_FILTER_IS_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST))
#define TUBA_API_NOTIFICATION_FILTER_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequestClass))

typedef struct _TubaAPINotificationFilterRequest TubaAPINotificationFilterRequest;
typedef struct _TubaAPINotificationFilterRequestClass TubaAPINotificationFilterRequestClass;
typedef struct _TubaAPINotificationFilterRequestPrivate TubaAPINotificationFilterRequestPrivate;
enum  {
	TUBA_API_NOTIFICATION_FILTER_REQUEST_0_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY,
	TUBA_API_NOTIFICATION_FILTER_REQUEST_NUM_PROPERTIES
};
static GParamSpec* tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_NUM_PROPERTIES];
#define _g_free0(var) (var = (g_free (var), NULL))

#define TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST (tuba_widgets_notification_request_get_type ())
#define TUBA_WIDGETS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequest))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_IS_NOTIFICATION_REQUEST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST))
#define TUBA_WIDGETS_NOTIFICATION_REQUEST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), TUBA_WIDGETS_TYPE_NOTIFICATION_REQUEST, TubaWidgetsNotificationRequestClass))

typedef struct _TubaWidgetsNotificationRequest TubaWidgetsNotificationRequest;
typedef struct _TubaWidgetsNotificationRequestClass TubaWidgetsNotificationRequestClass;
typedef struct _TubaAPIParamSpecNotificationFilter TubaAPIParamSpecNotificationFilter;

struct _TubaAPINotificationFilter {
	GTypeInstance parent_instance;
	volatile int ref_count;
	TubaAPINotificationFilterPrivate * priv;
};

struct _TubaAPINotificationFilterClass {
	GTypeClass parent_class;
	void (*finalize) (TubaAPINotificationFilter *self);
};

struct _TubaWidgetizableIface {
	GTypeInterface parent_iface;
	GtkWidget* (*to_widget) (TubaWidgetizable* self);
	void (*open) (TubaWidgetizable* self);
	void (*resolve_open) (TubaWidgetizable* self, TubaInstanceAccount* account);
};

struct _TubaEntity {
	GObject parent_instance;
	TubaEntityPrivate * priv;
};

struct _TubaEntityClass {
	GObjectClass parent_class;
	gboolean (*is_local) (TubaEntity* self, TubaInstanceAccount* account);
	GType (*deserialize_array_type) (TubaEntity* self, const gchar* prop);
};

struct _TubaAPINotificationFilterPolicy {
	TubaEntity parent_instance;
	TubaAPINotificationFilterPolicyPrivate * priv;
};

struct _TubaAPINotificationFilterPolicyClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINotificationFilterPolicyPrivate {
	gboolean _filter_not_following;
	gboolean _filter_not_followers;
	gboolean _filter_new_accounts;
	gboolean _filter_private_mentions;
	TubaAPINotificationFilterPolicySummary* _summary;
};

struct _TubaAPINotificationFilterPolicySummary {
	TubaEntity parent_instance;
	TubaAPINotificationFilterPolicySummaryPrivate * priv;
};

struct _TubaAPINotificationFilterPolicySummaryClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINotificationFilterPolicySummaryPrivate {
	gint32 _pending_requests_count;
	gint32 _pending_notifications_count;
};

struct _TubaAPINotificationFilterRequest {
	TubaEntity parent_instance;
	TubaAPINotificationFilterRequestPrivate * priv;
};

struct _TubaAPINotificationFilterRequestClass {
	TubaEntityClass parent_class;
};

struct _TubaAPINotificationFilterRequestPrivate {
	gchar* _id;
	gchar* _notifications_count;
	TubaAPIAccount* _account;
};

struct _TubaAPIParamSpecNotificationFilter {
	GParamSpec parent_instance;
};

static gpointer tuba_api_notification_filter_parent_class = NULL;
static gint TubaAPINotificationFilterPolicy_private_offset;
static gpointer tuba_api_notification_filter_policy_parent_class = NULL;
static gint TubaAPINotificationFilterPolicySummary_private_offset;
static gpointer tuba_api_notification_filter_policy_summary_parent_class = NULL;
static gint TubaAPINotificationFilterRequest_private_offset;
static gpointer tuba_api_notification_filter_request_parent_class = NULL;
static TubaWidgetizableIface * tuba_api_notification_filter_request_tuba_widgetizable_parent_iface = NULL;

VALA_EXTERN gpointer tuba_api_notification_filter_ref (gpointer instance);
VALA_EXTERN void tuba_api_notification_filter_unref (gpointer instance);
VALA_EXTERN GParamSpec* tuba_api_param_spec_notification_filter (const gchar* name,
                                                     const gchar* nick,
                                                     const gchar* blurb,
                                                     GType object_type,
                                                     GParamFlags flags);
VALA_EXTERN void tuba_api_value_set_notification_filter (GValue* value,
                                             gpointer v_object);
VALA_EXTERN void tuba_api_value_take_notification_filter (GValue* value,
                                              gpointer v_object);
VALA_EXTERN gpointer tuba_api_value_get_notification_filter (const GValue* value);
VALA_EXTERN GType tuba_api_notification_filter_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationFilter, tuba_api_notification_filter_unref)
VALA_EXTERN TubaAPINotificationFilter* tuba_api_notification_filter_new (void);
VALA_EXTERN TubaAPINotificationFilter* tuba_api_notification_filter_construct (GType object_type);
VALA_EXTERN GType tuba_entity_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaEntity, g_object_unref)
VALA_EXTERN GType tuba_api_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPIAccount, g_object_unref)
VALA_EXTERN GType tuba_instance_account_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaInstanceAccount, g_object_unref)
VALA_EXTERN GType tuba_widgetizable_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetizable, g_object_unref)
VALA_EXTERN GType tuba_api_notification_filter_policy_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationFilterPolicy, g_object_unref)
VALA_EXTERN GType tuba_api_notification_filter_policy_summary_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationFilterPolicySummary, g_object_unref)
VALA_EXTERN TubaAPINotificationFilterPolicy* tuba_api_notification_filter_policy_from (JsonNode* node,
                                                                           GError** error);
VALA_EXTERN TubaEntity* tuba_entity_from_json (GType type,
                                   JsonNode* node,
                                   GError** error);
VALA_EXTERN TubaAPINotificationFilterPolicy* tuba_api_notification_filter_policy_new (void);
VALA_EXTERN TubaAPINotificationFilterPolicy* tuba_api_notification_filter_policy_construct (GType object_type);
VALA_EXTERN TubaEntity* tuba_entity_new (void);
VALA_EXTERN TubaEntity* tuba_entity_construct (GType object_type);
VALA_EXTERN gboolean tuba_api_notification_filter_policy_get_filter_not_following (TubaAPINotificationFilterPolicy* self);
VALA_EXTERN void tuba_api_notification_filter_policy_set_filter_not_following (TubaAPINotificationFilterPolicy* self,
                                                                   gboolean value);
VALA_EXTERN gboolean tuba_api_notification_filter_policy_get_filter_not_followers (TubaAPINotificationFilterPolicy* self);
VALA_EXTERN void tuba_api_notification_filter_policy_set_filter_not_followers (TubaAPINotificationFilterPolicy* self,
                                                                   gboolean value);
VALA_EXTERN gboolean tuba_api_notification_filter_policy_get_filter_new_accounts (TubaAPINotificationFilterPolicy* self);
VALA_EXTERN void tuba_api_notification_filter_policy_set_filter_new_accounts (TubaAPINotificationFilterPolicy* self,
                                                                  gboolean value);
VALA_EXTERN gboolean tuba_api_notification_filter_policy_get_filter_private_mentions (TubaAPINotificationFilterPolicy* self);
VALA_EXTERN void tuba_api_notification_filter_policy_set_filter_private_mentions (TubaAPINotificationFilterPolicy* self,
                                                                      gboolean value);
VALA_EXTERN TubaAPINotificationFilterPolicySummary* tuba_api_notification_filter_policy_get_summary (TubaAPINotificationFilterPolicy* self);
VALA_EXTERN void tuba_api_notification_filter_policy_set_summary (TubaAPINotificationFilterPolicy* self,
                                                      TubaAPINotificationFilterPolicySummary* value);
VALA_EXTERN TubaAPINotificationFilterPolicySummary* tuba_api_notification_filter_policy_summary_new (void);
VALA_EXTERN TubaAPINotificationFilterPolicySummary* tuba_api_notification_filter_policy_summary_construct (GType object_type);
VALA_EXTERN gint32 tuba_api_notification_filter_policy_summary_get_pending_requests_count (TubaAPINotificationFilterPolicySummary* self);
VALA_EXTERN void tuba_api_notification_filter_policy_summary_set_pending_requests_count (TubaAPINotificationFilterPolicySummary* self,
                                                                             gint32 value);
VALA_EXTERN gint32 tuba_api_notification_filter_policy_summary_get_pending_notifications_count (TubaAPINotificationFilterPolicySummary* self);
VALA_EXTERN void tuba_api_notification_filter_policy_summary_set_pending_notifications_count (TubaAPINotificationFilterPolicySummary* self,
                                                                                  gint32 value);
static void tuba_api_notification_filter_policy_summary_finalize (GObject * obj);
static GType tuba_api_notification_filter_policy_summary_get_type_once (void);
static void _vala_tuba_api_notification_filter_policy_summary_get_property (GObject * object,
                                                                     guint property_id,
                                                                     GValue * value,
                                                                     GParamSpec * pspec);
static void _vala_tuba_api_notification_filter_policy_summary_set_property (GObject * object,
                                                                     guint property_id,
                                                                     const GValue * value,
                                                                     GParamSpec * pspec);
static void tuba_api_notification_filter_policy_finalize (GObject * obj);
static GType tuba_api_notification_filter_policy_get_type_once (void);
static void _vala_tuba_api_notification_filter_policy_get_property (GObject * object,
                                                             guint property_id,
                                                             GValue * value,
                                                             GParamSpec * pspec);
static void _vala_tuba_api_notification_filter_policy_set_property (GObject * object,
                                                             guint property_id,
                                                             const GValue * value,
                                                             GParamSpec * pspec);
VALA_EXTERN GType tuba_api_notification_filter_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaAPINotificationFilterRequest, g_object_unref)
static GtkWidget* tuba_api_notification_filter_request_real_to_widget (TubaWidgetizable* base);
VALA_EXTERN TubaWidgetsNotificationRequest* tuba_widgets_notification_request_new (TubaAPINotificationFilterRequest* request);
VALA_EXTERN TubaWidgetsNotificationRequest* tuba_widgets_notification_request_construct (GType object_type,
                                                                             TubaAPINotificationFilterRequest* request);
VALA_EXTERN GType tuba_widgets_notification_request_get_type (void) G_GNUC_CONST ;
G_DEFINE_AUTOPTR_CLEANUP_FUNC (TubaWidgetsNotificationRequest, g_object_unref)
VALA_EXTERN TubaAPINotificationFilterRequest* tuba_api_notification_filter_request_from (JsonNode* node,
                                                                             GError** error);
VALA_EXTERN TubaAPINotificationFilterRequest* tuba_api_notification_filter_request_new (void);
VALA_EXTERN TubaAPINotificationFilterRequest* tuba_api_notification_filter_request_construct (GType object_type);
VALA_EXTERN const gchar* tuba_api_notification_filter_request_get_id (TubaAPINotificationFilterRequest* self);
VALA_EXTERN void tuba_api_notification_filter_request_set_id (TubaAPINotificationFilterRequest* self,
                                                  const gchar* value);
VALA_EXTERN const gchar* tuba_api_notification_filter_request_get_notifications_count (TubaAPINotificationFilterRequest* self);
VALA_EXTERN void tuba_api_notification_filter_request_set_notifications_count (TubaAPINotificationFilterRequest* self,
                                                                   const gchar* value);
VALA_EXTERN TubaAPIAccount* tuba_api_notification_filter_request_get_account (TubaAPINotificationFilterRequest* self);
VALA_EXTERN void tuba_api_notification_filter_request_set_account (TubaAPINotificationFilterRequest* self,
                                                       TubaAPIAccount* value);
VALA_EXTERN GtkWidget* tuba_widgetizable_to_widget (TubaWidgetizable* self);
static void tuba_api_notification_filter_request_finalize (GObject * obj);
static GType tuba_api_notification_filter_request_get_type_once (void);
static void _vala_tuba_api_notification_filter_request_get_property (GObject * object,
                                                              guint property_id,
                                                              GValue * value,
                                                              GParamSpec * pspec);
static void _vala_tuba_api_notification_filter_request_set_property (GObject * object,
                                                              guint property_id,
                                                              const GValue * value,
                                                              GParamSpec * pspec);
static void tuba_api_notification_filter_finalize (TubaAPINotificationFilter * obj);
static GType tuba_api_notification_filter_get_type_once (void);

TubaAPINotificationFilter*
tuba_api_notification_filter_construct (GType object_type)
{
	TubaAPINotificationFilter* self = NULL;
	self = (TubaAPINotificationFilter*) g_type_create_instance (object_type);
	return self;
}

TubaAPINotificationFilter*
tuba_api_notification_filter_new (void)
{
	return tuba_api_notification_filter_construct (TUBA_API_TYPE_NOTIFICATION_FILTER);
}

static inline gpointer
tuba_api_notification_filter_policy_get_instance_private (TubaAPINotificationFilterPolicy* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotificationFilterPolicy_private_offset);
}

static gpointer
_g_object_ref0 (gpointer self)
{
	return self ? g_object_ref (self) : NULL;
}

TubaAPINotificationFilterPolicy*
tuba_api_notification_filter_policy_from (JsonNode* node,
                                          GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPINotificationFilterPolicy* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPINotificationFilterPolicy* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_NOTIFICATION_FILTER_IS_POLICY (_tmp0_) ? ((TubaAPINotificationFilterPolicy*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPINotificationFilterPolicy*
tuba_api_notification_filter_policy_construct (GType object_type)
{
	TubaAPINotificationFilterPolicy * self = NULL;
	self = (TubaAPINotificationFilterPolicy*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotificationFilterPolicy*
tuba_api_notification_filter_policy_new (void)
{
	return tuba_api_notification_filter_policy_construct (TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY);
}

gboolean
tuba_api_notification_filter_policy_get_filter_not_following (TubaAPINotificationFilterPolicy* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_filter_not_following;
	return result;
}

void
tuba_api_notification_filter_policy_set_filter_not_following (TubaAPINotificationFilterPolicy* self,
                                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_get_filter_not_following (self);
	if (old_value != value) {
		self->priv->_filter_not_following = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY]);
	}
}

gboolean
tuba_api_notification_filter_policy_get_filter_not_followers (TubaAPINotificationFilterPolicy* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_filter_not_followers;
	return result;
}

void
tuba_api_notification_filter_policy_set_filter_not_followers (TubaAPINotificationFilterPolicy* self,
                                                              gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_get_filter_not_followers (self);
	if (old_value != value) {
		self->priv->_filter_not_followers = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY]);
	}
}

gboolean
tuba_api_notification_filter_policy_get_filter_new_accounts (TubaAPINotificationFilterPolicy* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_filter_new_accounts;
	return result;
}

void
tuba_api_notification_filter_policy_set_filter_new_accounts (TubaAPINotificationFilterPolicy* self,
                                                             gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_get_filter_new_accounts (self);
	if (old_value != value) {
		self->priv->_filter_new_accounts = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY]);
	}
}

gboolean
tuba_api_notification_filter_policy_get_filter_private_mentions (TubaAPINotificationFilterPolicy* self)
{
	gboolean result;
	g_return_val_if_fail (self != NULL, FALSE);
	result = self->priv->_filter_private_mentions;
	return result;
}

void
tuba_api_notification_filter_policy_set_filter_private_mentions (TubaAPINotificationFilterPolicy* self,
                                                                 gboolean value)
{
	gboolean old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_get_filter_private_mentions (self);
	if (old_value != value) {
		self->priv->_filter_private_mentions = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY]);
	}
}

TubaAPINotificationFilterPolicySummary*
tuba_api_notification_filter_policy_get_summary (TubaAPINotificationFilterPolicy* self)
{
	TubaAPINotificationFilterPolicySummary* result;
	TubaAPINotificationFilterPolicySummary* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_summary;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_filter_policy_set_summary (TubaAPINotificationFilterPolicy* self,
                                                 TubaAPINotificationFilterPolicySummary* value)
{
	TubaAPINotificationFilterPolicySummary* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_get_summary (self);
	if (old_value != value) {
		TubaAPINotificationFilterPolicySummary* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_summary);
		self->priv->_summary = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY]);
	}
}

static inline gpointer
tuba_api_notification_filter_policy_summary_get_instance_private (TubaAPINotificationFilterPolicySummary* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotificationFilterPolicySummary_private_offset);
}

TubaAPINotificationFilterPolicySummary*
tuba_api_notification_filter_policy_summary_construct (GType object_type)
{
	TubaAPINotificationFilterPolicySummary * self = NULL;
	self = (TubaAPINotificationFilterPolicySummary*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotificationFilterPolicySummary*
tuba_api_notification_filter_policy_summary_new (void)
{
	return tuba_api_notification_filter_policy_summary_construct (TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY);
}

gint32
tuba_api_notification_filter_policy_summary_get_pending_requests_count (TubaAPINotificationFilterPolicySummary* self)
{
	gint32 result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_pending_requests_count;
	return result;
}

void
tuba_api_notification_filter_policy_summary_set_pending_requests_count (TubaAPINotificationFilterPolicySummary* self,
                                                                        gint32 value)
{
	gint32 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_summary_get_pending_requests_count (self);
	if (old_value != value) {
		self->priv->_pending_requests_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_summary_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY]);
	}
}

gint32
tuba_api_notification_filter_policy_summary_get_pending_notifications_count (TubaAPINotificationFilterPolicySummary* self)
{
	gint32 result;
	g_return_val_if_fail (self != NULL, -1);
	result = self->priv->_pending_notifications_count;
	return result;
}

void
tuba_api_notification_filter_policy_summary_set_pending_notifications_count (TubaAPINotificationFilterPolicySummary* self,
                                                                             gint32 value)
{
	gint32 old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_policy_summary_get_pending_notifications_count (self);
	if (old_value != value) {
		self->priv->_pending_notifications_count = value;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_policy_summary_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY]);
	}
}

static void
tuba_api_notification_filter_policy_summary_class_init (TubaAPINotificationFilterPolicySummaryClass * klass,
                                                        gpointer klass_data)
{
	tuba_api_notification_filter_policy_summary_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotificationFilterPolicySummary_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_filter_policy_summary_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_filter_policy_summary_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_filter_policy_summary_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY, tuba_api_notification_filter_policy_summary_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY] = g_param_spec_int ("pending-requests-count", "pending-requests-count", "pending-requests-count", G_MININT, G_MAXINT, (gint32) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY, tuba_api_notification_filter_policy_summary_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY] = g_param_spec_int ("pending-notifications-count", "pending-notifications-count", "pending-notifications-count", G_MININT, G_MAXINT, (gint32) 0, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_filter_policy_summary_instance_init (TubaAPINotificationFilterPolicySummary * self,
                                                           gpointer klass)
{
	self->priv = tuba_api_notification_filter_policy_summary_get_instance_private (self);
	self->priv->_pending_requests_count = (gint32) 0;
	self->priv->_pending_notifications_count = (gint32) 0;
}

static void
tuba_api_notification_filter_policy_summary_finalize (GObject * obj)
{
	TubaAPINotificationFilterPolicySummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummary);
	G_OBJECT_CLASS (tuba_api_notification_filter_policy_summary_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_filter_policy_summary_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationFilterPolicySummaryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_filter_policy_summary_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationFilterPolicySummary), 0, (GInstanceInitFunc) tuba_api_notification_filter_policy_summary_instance_init, NULL };
	GType tuba_api_notification_filter_policy_summary_type_id;
	tuba_api_notification_filter_policy_summary_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotificationFilterPolicySummary", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINotificationFilterPolicySummary_private_offset = g_type_add_instance_private (tuba_api_notification_filter_policy_summary_type_id, sizeof (TubaAPINotificationFilterPolicySummaryPrivate));
	return tuba_api_notification_filter_policy_summary_type_id;
}

GType
tuba_api_notification_filter_policy_summary_get_type (void)
{
	static GType tuba_api_notification_filter_policy_summary_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_filter_policy_summary_type_id__once)) {
		GType tuba_api_notification_filter_policy_summary_type_id;
		tuba_api_notification_filter_policy_summary_type_id = tuba_api_notification_filter_policy_summary_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_filter_policy_summary_type_id__once, tuba_api_notification_filter_policy_summary_type_id);
	}
	return tuba_api_notification_filter_policy_summary_type_id__once;
}

static void
_vala_tuba_api_notification_filter_policy_summary_get_property (GObject * object,
                                                                guint property_id,
                                                                GValue * value,
                                                                GParamSpec * pspec)
{
	TubaAPINotificationFilterPolicySummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummary);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY:
		g_value_set_int (value, tuba_api_notification_filter_policy_summary_get_pending_requests_count (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY:
		g_value_set_int (value, tuba_api_notification_filter_policy_summary_get_pending_notifications_count (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_filter_policy_summary_set_property (GObject * object,
                                                                guint property_id,
                                                                const GValue * value,
                                                                GParamSpec * pspec)
{
	TubaAPINotificationFilterPolicySummary * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, TubaAPINotificationFilterPolicySummary);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_REQUESTS_COUNT_PROPERTY:
		tuba_api_notification_filter_policy_summary_set_pending_requests_count (self, g_value_get_int (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PENDING_NOTIFICATIONS_COUNT_PROPERTY:
		tuba_api_notification_filter_policy_summary_set_pending_notifications_count (self, g_value_get_int (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_notification_filter_policy_class_init (TubaAPINotificationFilterPolicyClass * klass,
                                                gpointer klass_data)
{
	tuba_api_notification_filter_policy_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotificationFilterPolicy_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_filter_policy_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_filter_policy_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_filter_policy_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY] = g_param_spec_boolean ("filter-not-following", "filter-not-following", "filter-not-following", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY] = g_param_spec_boolean ("filter-not-followers", "filter-not-followers", "filter-not-followers", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY] = g_param_spec_boolean ("filter-new-accounts", "filter-new-accounts", "filter-new-accounts", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY] = g_param_spec_boolean ("filter-private-mentions", "filter-private-mentions", "filter-private-mentions", FALSE, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY, tuba_api_notification_filter_policy_properties[TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY] = g_param_spec_object ("summary", "summary", "summary", TUBA_API_NOTIFICATION_FILTER_POLICY_TYPE_SUMMARY, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_filter_policy_instance_init (TubaAPINotificationFilterPolicy * self,
                                                   gpointer klass)
{
	self->priv = tuba_api_notification_filter_policy_get_instance_private (self);
	self->priv->_filter_not_following = FALSE;
	self->priv->_filter_not_followers = FALSE;
	self->priv->_filter_new_accounts = FALSE;
	self->priv->_filter_private_mentions = FALSE;
	self->priv->_summary = NULL;
}

static void
tuba_api_notification_filter_policy_finalize (GObject * obj)
{
	TubaAPINotificationFilterPolicy * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicy);
	_g_object_unref0 (self->priv->_summary);
	G_OBJECT_CLASS (tuba_api_notification_filter_policy_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_filter_policy_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationFilterPolicyClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_filter_policy_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationFilterPolicy), 0, (GInstanceInitFunc) tuba_api_notification_filter_policy_instance_init, NULL };
	GType tuba_api_notification_filter_policy_type_id;
	tuba_api_notification_filter_policy_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotificationFilterPolicy", &g_define_type_info, G_TYPE_FLAG_NONE);
	TubaAPINotificationFilterPolicy_private_offset = g_type_add_instance_private (tuba_api_notification_filter_policy_type_id, sizeof (TubaAPINotificationFilterPolicyPrivate));
	return tuba_api_notification_filter_policy_type_id;
}

GType
tuba_api_notification_filter_policy_get_type (void)
{
	static GType tuba_api_notification_filter_policy_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_filter_policy_type_id__once)) {
		GType tuba_api_notification_filter_policy_type_id;
		tuba_api_notification_filter_policy_type_id = tuba_api_notification_filter_policy_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_filter_policy_type_id__once, tuba_api_notification_filter_policy_type_id);
	}
	return tuba_api_notification_filter_policy_type_id__once;
}

static void
_vala_tuba_api_notification_filter_policy_get_property (GObject * object,
                                                        guint property_id,
                                                        GValue * value,
                                                        GParamSpec * pspec)
{
	TubaAPINotificationFilterPolicy * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicy);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY:
		g_value_set_boolean (value, tuba_api_notification_filter_policy_get_filter_not_following (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY:
		g_value_set_boolean (value, tuba_api_notification_filter_policy_get_filter_not_followers (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY:
		g_value_set_boolean (value, tuba_api_notification_filter_policy_get_filter_new_accounts (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY:
		g_value_set_boolean (value, tuba_api_notification_filter_policy_get_filter_private_mentions (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY:
		g_value_set_object (value, tuba_api_notification_filter_policy_get_summary (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_filter_policy_set_property (GObject * object,
                                                        guint property_id,
                                                        const GValue * value,
                                                        GParamSpec * pspec)
{
	TubaAPINotificationFilterPolicy * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_TYPE_POLICY, TubaAPINotificationFilterPolicy);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWING_PROPERTY:
		tuba_api_notification_filter_policy_set_filter_not_following (self, g_value_get_boolean (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NOT_FOLLOWERS_PROPERTY:
		tuba_api_notification_filter_policy_set_filter_not_followers (self, g_value_get_boolean (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_NEW_ACCOUNTS_PROPERTY:
		tuba_api_notification_filter_policy_set_filter_new_accounts (self, g_value_get_boolean (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_FILTER_PRIVATE_MENTIONS_PROPERTY:
		tuba_api_notification_filter_policy_set_filter_private_mentions (self, g_value_get_boolean (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_POLICY_SUMMARY_PROPERTY:
		tuba_api_notification_filter_policy_set_summary (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static inline gpointer
tuba_api_notification_filter_request_get_instance_private (TubaAPINotificationFilterRequest* self)
{
	return G_STRUCT_MEMBER_P (self, TubaAPINotificationFilterRequest_private_offset);
}

static GtkWidget*
tuba_api_notification_filter_request_real_to_widget (TubaWidgetizable* base)
{
	TubaAPINotificationFilterRequest * self;
	TubaWidgetsNotificationRequest* _tmp0_;
	GtkWidget* result;
	self = (TubaAPINotificationFilterRequest*) base;
	_tmp0_ = tuba_widgets_notification_request_new (self);
	g_object_ref_sink (_tmp0_);
	result = (GtkWidget*) _tmp0_;
	return result;
}

TubaAPINotificationFilterRequest*
tuba_api_notification_filter_request_from (JsonNode* node,
                                           GError** error)
{
	TubaEntity* _tmp0_ = NULL;
	TubaEntity* _tmp1_;
	TubaAPINotificationFilterRequest* _tmp2_;
	GError* _inner_error0_ = NULL;
	TubaAPINotificationFilterRequest* result;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = tuba_entity_from_json (TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, node, &_inner_error0_);
	_tmp0_ = _tmp1_;
	if (G_UNLIKELY (_inner_error0_ != NULL)) {
		g_propagate_error (error, _inner_error0_);
		return NULL;
	}
	_tmp2_ = _g_object_ref0 (TUBA_API_NOTIFICATION_FILTER_IS_REQUEST (_tmp0_) ? ((TubaAPINotificationFilterRequest*) _tmp0_) : NULL);
	result = _tmp2_;
	_g_object_unref0 (_tmp0_);
	return result;
}

TubaAPINotificationFilterRequest*
tuba_api_notification_filter_request_construct (GType object_type)
{
	TubaAPINotificationFilterRequest * self = NULL;
	self = (TubaAPINotificationFilterRequest*) tuba_entity_construct (object_type);
	return self;
}

TubaAPINotificationFilterRequest*
tuba_api_notification_filter_request_new (void)
{
	return tuba_api_notification_filter_request_construct (TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST);
}

const gchar*
tuba_api_notification_filter_request_get_id (TubaAPINotificationFilterRequest* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_id;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_filter_request_set_id (TubaAPINotificationFilterRequest* self,
                                             const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_request_get_id (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_id);
		self->priv->_id = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY]);
	}
}

const gchar*
tuba_api_notification_filter_request_get_notifications_count (TubaAPINotificationFilterRequest* self)
{
	const gchar* result;
	const gchar* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_notifications_count;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_filter_request_set_notifications_count (TubaAPINotificationFilterRequest* self,
                                                              const gchar* value)
{
	gchar* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_request_get_notifications_count (self);
	if (g_strcmp0 (value, old_value) != 0) {
		gchar* _tmp0_;
		_tmp0_ = g_strdup (value);
		_g_free0 (self->priv->_notifications_count);
		self->priv->_notifications_count = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY]);
	}
}

TubaAPIAccount*
tuba_api_notification_filter_request_get_account (TubaAPINotificationFilterRequest* self)
{
	TubaAPIAccount* result;
	TubaAPIAccount* _tmp0_;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->priv->_account;
	result = _tmp0_;
	return result;
}

void
tuba_api_notification_filter_request_set_account (TubaAPINotificationFilterRequest* self,
                                                  TubaAPIAccount* value)
{
	TubaAPIAccount* old_value;
	g_return_if_fail (self != NULL);
	old_value = tuba_api_notification_filter_request_get_account (self);
	if (old_value != value) {
		TubaAPIAccount* _tmp0_;
		_tmp0_ = _g_object_ref0 (value);
		_g_object_unref0 (self->priv->_account);
		self->priv->_account = _tmp0_;
		g_object_notify_by_pspec ((GObject *) self, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY]);
	}
}

static void
tuba_api_notification_filter_request_class_init (TubaAPINotificationFilterRequestClass * klass,
                                                 gpointer klass_data)
{
	tuba_api_notification_filter_request_parent_class = g_type_class_peek_parent (klass);
	g_type_class_adjust_private_offset (klass, &TubaAPINotificationFilterRequest_private_offset);
	G_OBJECT_CLASS (klass)->get_property = _vala_tuba_api_notification_filter_request_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_tuba_api_notification_filter_request_set_property;
	G_OBJECT_CLASS (klass)->finalize = tuba_api_notification_filter_request_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY] = g_param_spec_string ("id", "id", "id", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY] = g_param_spec_string ("notifications-count", "notifications-count", "notifications-count", NULL, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY, tuba_api_notification_filter_request_properties[TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY] = g_param_spec_object ("account", "account", "account", TUBA_API_TYPE_ACCOUNT, G_PARAM_STATIC_STRINGS | G_PARAM_READABLE | G_PARAM_WRITABLE));
}

static void
tuba_api_notification_filter_request_tuba_widgetizable_interface_init (TubaWidgetizableIface * iface,
                                                                       gpointer iface_data)
{
	tuba_api_notification_filter_request_tuba_widgetizable_parent_iface = g_type_interface_peek_parent (iface);
	iface->to_widget = (GtkWidget* (*) (TubaWidgetizable*)) tuba_api_notification_filter_request_real_to_widget;
}

static void
tuba_api_notification_filter_request_instance_init (TubaAPINotificationFilterRequest * self,
                                                    gpointer klass)
{
	gchar* _tmp0_;
	self->priv = tuba_api_notification_filter_request_get_instance_private (self);
	_tmp0_ = g_strdup ("0");
	self->priv->_notifications_count = _tmp0_;
}

static void
tuba_api_notification_filter_request_finalize (GObject * obj)
{
	TubaAPINotificationFilterRequest * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequest);
	_g_free0 (self->priv->_id);
	_g_free0 (self->priv->_notifications_count);
	_g_object_unref0 (self->priv->_account);
	G_OBJECT_CLASS (tuba_api_notification_filter_request_parent_class)->finalize (obj);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_filter_request_get_type_once (void)
{
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationFilterRequestClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_filter_request_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationFilterRequest), 0, (GInstanceInitFunc) tuba_api_notification_filter_request_instance_init, NULL };
	static const GInterfaceInfo tuba_widgetizable_info = { (GInterfaceInitFunc) tuba_api_notification_filter_request_tuba_widgetizable_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
	GType tuba_api_notification_filter_request_type_id;
	tuba_api_notification_filter_request_type_id = g_type_register_static (TUBA_TYPE_ENTITY, "TubaAPINotificationFilterRequest", &g_define_type_info, G_TYPE_FLAG_NONE);
	g_type_add_interface_static (tuba_api_notification_filter_request_type_id, TUBA_TYPE_WIDGETIZABLE, &tuba_widgetizable_info);
	TubaAPINotificationFilterRequest_private_offset = g_type_add_instance_private (tuba_api_notification_filter_request_type_id, sizeof (TubaAPINotificationFilterRequestPrivate));
	return tuba_api_notification_filter_request_type_id;
}

GType
tuba_api_notification_filter_request_get_type (void)
{
	static GType tuba_api_notification_filter_request_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_filter_request_type_id__once)) {
		GType tuba_api_notification_filter_request_type_id;
		tuba_api_notification_filter_request_type_id = tuba_api_notification_filter_request_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_filter_request_type_id__once, tuba_api_notification_filter_request_type_id);
	}
	return tuba_api_notification_filter_request_type_id__once;
}

static void
_vala_tuba_api_notification_filter_request_get_property (GObject * object,
                                                         guint property_id,
                                                         GValue * value,
                                                         GParamSpec * pspec)
{
	TubaAPINotificationFilterRequest * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequest);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY:
		g_value_set_string (value, tuba_api_notification_filter_request_get_id (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY:
		g_value_set_string (value, tuba_api_notification_filter_request_get_notifications_count (self));
		break;
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY:
		g_value_set_object (value, tuba_api_notification_filter_request_get_account (self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
_vala_tuba_api_notification_filter_request_set_property (GObject * object,
                                                         guint property_id,
                                                         const GValue * value,
                                                         GParamSpec * pspec)
{
	TubaAPINotificationFilterRequest * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, TUBA_API_NOTIFICATION_FILTER_TYPE_REQUEST, TubaAPINotificationFilterRequest);
	switch (property_id) {
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_ID_PROPERTY:
		tuba_api_notification_filter_request_set_id (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_NOTIFICATIONS_COUNT_PROPERTY:
		tuba_api_notification_filter_request_set_notifications_count (self, g_value_get_string (value));
		break;
		case TUBA_API_NOTIFICATION_FILTER_REQUEST_ACCOUNT_PROPERTY:
		tuba_api_notification_filter_request_set_account (self, g_value_get_object (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}

static void
tuba_api_value_notification_filter_init (GValue* value)
{
	value->data[0].v_pointer = NULL;
}

static void
tuba_api_value_notification_filter_free_value (GValue* value)
{
	if (value->data[0].v_pointer) {
		tuba_api_notification_filter_unref (value->data[0].v_pointer);
	}
}

static void
tuba_api_value_notification_filter_copy_value (const GValue* src_value,
                                               GValue* dest_value)
{
	if (src_value->data[0].v_pointer) {
		dest_value->data[0].v_pointer = tuba_api_notification_filter_ref (src_value->data[0].v_pointer);
	} else {
		dest_value->data[0].v_pointer = NULL;
	}
}

static gpointer
tuba_api_value_notification_filter_peek_pointer (const GValue* value)
{
	return value->data[0].v_pointer;
}

static gchar*
tuba_api_value_notification_filter_collect_value (GValue* value,
                                                  guint n_collect_values,
                                                  GTypeCValue* collect_values,
                                                  guint collect_flags)
{
	if (collect_values[0].v_pointer) {
		TubaAPINotificationFilter * object;
		object = collect_values[0].v_pointer;
		if (object->parent_instance.g_class == NULL) {
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
		}
		value->data[0].v_pointer = tuba_api_notification_filter_ref (object);
	} else {
		value->data[0].v_pointer = NULL;
	}
	return NULL;
}

static gchar*
tuba_api_value_notification_filter_lcopy_value (const GValue* value,
                                                guint n_collect_values,
                                                GTypeCValue* collect_values,
                                                guint collect_flags)
{
	TubaAPINotificationFilter ** object_p;
	object_p = collect_values[0].v_pointer;
	if (!object_p) {
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
	}
	if (!value->data[0].v_pointer) {
		*object_p = NULL;
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
		*object_p = value->data[0].v_pointer;
	} else {
		*object_p = tuba_api_notification_filter_ref (value->data[0].v_pointer);
	}
	return NULL;
}

GParamSpec*
tuba_api_param_spec_notification_filter (const gchar* name,
                                         const gchar* nick,
                                         const gchar* blurb,
                                         GType object_type,
                                         GParamFlags flags)
{
	TubaAPIParamSpecNotificationFilter* spec;
	g_return_val_if_fail (g_type_is_a (object_type, TUBA_API_TYPE_NOTIFICATION_FILTER), NULL);
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
	G_PARAM_SPEC (spec)->value_type = object_type;
	return G_PARAM_SPEC (spec);
}

gpointer
tuba_api_value_get_notification_filter (const GValue* value)
{
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_API_TYPE_NOTIFICATION_FILTER), NULL);
	return value->data[0].v_pointer;
}

void
tuba_api_value_set_notification_filter (GValue* value,
                                        gpointer v_object)
{
	TubaAPINotificationFilter * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_API_TYPE_NOTIFICATION_FILTER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_API_TYPE_NOTIFICATION_FILTER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
		tuba_api_notification_filter_ref (value->data[0].v_pointer);
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_api_notification_filter_unref (old);
	}
}

void
tuba_api_value_take_notification_filter (GValue* value,
                                         gpointer v_object)
{
	TubaAPINotificationFilter * old;
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, TUBA_API_TYPE_NOTIFICATION_FILTER));
	old = value->data[0].v_pointer;
	if (v_object) {
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, TUBA_API_TYPE_NOTIFICATION_FILTER));
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
		value->data[0].v_pointer = v_object;
	} else {
		value->data[0].v_pointer = NULL;
	}
	if (old) {
		tuba_api_notification_filter_unref (old);
	}
}

static void
tuba_api_notification_filter_class_init (TubaAPINotificationFilterClass * klass,
                                         gpointer klass_data)
{
	tuba_api_notification_filter_parent_class = g_type_class_peek_parent (klass);
	((TubaAPINotificationFilterClass *) klass)->finalize = tuba_api_notification_filter_finalize;
}

static void
tuba_api_notification_filter_instance_init (TubaAPINotificationFilter * self,
                                            gpointer klass)
{
	self->ref_count = 1;
}

static void
tuba_api_notification_filter_finalize (TubaAPINotificationFilter * obj)
{
	TubaAPINotificationFilter * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, TUBA_API_TYPE_NOTIFICATION_FILTER, TubaAPINotificationFilter);
	g_signal_handlers_destroy (self);
}

 G_GNUC_NO_INLINE static GType
tuba_api_notification_filter_get_type_once (void)
{
	static const GTypeValueTable g_define_type_value_table = { tuba_api_value_notification_filter_init, tuba_api_value_notification_filter_free_value, tuba_api_value_notification_filter_copy_value, tuba_api_value_notification_filter_peek_pointer, "p", tuba_api_value_notification_filter_collect_value, "p", tuba_api_value_notification_filter_lcopy_value };
	static const GTypeInfo g_define_type_info = { sizeof (TubaAPINotificationFilterClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) tuba_api_notification_filter_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (TubaAPINotificationFilter), 0, (GInstanceInitFunc) tuba_api_notification_filter_instance_init, &g_define_type_value_table };
	static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
	GType tuba_api_notification_filter_type_id;
	tuba_api_notification_filter_type_id = g_type_register_fundamental (g_type_fundamental_next (), "TubaAPINotificationFilter", &g_define_type_info, &g_define_type_fundamental_info, G_TYPE_FLAG_NONE);
	return tuba_api_notification_filter_type_id;
}

GType
tuba_api_notification_filter_get_type (void)
{
	static GType tuba_api_notification_filter_type_id__once = 0;
	if (g_once_init_enter_pointer (&tuba_api_notification_filter_type_id__once)) {
		GType tuba_api_notification_filter_type_id;
		tuba_api_notification_filter_type_id = tuba_api_notification_filter_get_type_once ();
		g_once_init_leave_pointer (&tuba_api_notification_filter_type_id__once, tuba_api_notification_filter_type_id);
	}
	return tuba_api_notification_filter_type_id__once;
}

gpointer
tuba_api_notification_filter_ref (gpointer instance)
{
	TubaAPINotificationFilter * self;
	self = instance;
	g_atomic_int_inc (&self->ref_count);
	return instance;
}

void
tuba_api_notification_filter_unref (gpointer instance)
{
	TubaAPINotificationFilter * self;
	self = instance;
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
		TUBA_API_NOTIFICATION_FILTER_GET_CLASS (self)->finalize (self);
		g_type_free_instance ((GTypeInstance *) self);
	}
}

